"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetEvaluationReviewCommitments = exports.SaveEvaluationReview = exports.GetEvaluationReview = exports.EvaluationReviewMSSql = void 0;
var log4js = require("log4js");
var utilities_1 = require("../../shared/utilities");
var sql = require('mssql');
var logger = log4js.getLogger('Sql');
var sqlConn;
function EvaluationReviewMSSql(app) {
    sqlConn = app.get('sqlConn');
}
exports.EvaluationReviewMSSql = EvaluationReviewMSSql;
function GetEvaluationReview(vcc, evaluationPlanId, interactionId, supervisorId, agentId) {
    return new sql.Request(sqlConn)
        .input('VCC', sql.VarChar(50), vcc)
        .input('EvaluationPlanId', sql.VarChar(50), evaluationPlanId)
        .input('InteractionId', sql.VarChar(250), interactionId)
        .input('SupervisorId', sql.VarChar(50), supervisorId)
        .input('AgentId', sql.VarChar(50), agentId)
        .execute('GetEvaluationReview')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var evaluationReview = (recordset && recordset.length > 0 ? recordset[0] : null);
        if (evaluationReview) {
            var evaluationReviewCommitments = (recordsets && recordsets.length > 1 ? recordsets[1] : []);
            evaluationReview.commitments = evaluationReviewCommitments;
        }
        return Promise.resolve(evaluationReview);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetEvaluationReview = GetEvaluationReview;
function SaveEvaluationReview(vcc, evaluationReview, saveUserId) {
    if (!evaluationReview.id)
        evaluationReview.id = utilities_1.guid();
    var saveEvaluationReviewResult = false;
    return new sql.Request(sqlConn)
        .input('VCC', sql.VarChar(50), vcc)
        .input('EvaluationReviewId', sql.VarChar(50), evaluationReview.id)
        .input('EvaluationPlanId', sql.VarChar(50), evaluationReview.evaluationPlanId)
        .input('InteractionId', sql.VarChar(250), evaluationReview.interactionId)
        .input('SupervisorId', sql.VarChar(50), evaluationReview.supervisorId)
        .input('Review', sql.VarChar(500), evaluationReview.review)
        .input('SaveUserId', sql.VarChar(50), saveUserId)
        .execute('SaveEvaluationReview')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        saveEvaluationReviewResult = output && output.id ? true : false;
        evaluationReview.id = output.id;
        var promiseArray = [];
        evaluationReview.commitments.map(function (c) {
            c.evaluationReviewId = evaluationReview.id;
            promiseArray.push(SaveEvaluationReviewCommitment(vcc, c, saveUserId));
        });
        return Promise.all(promiseArray);
    })
        .then(function (results) {
        console.log(results);
        return Promise.resolve(saveEvaluationReviewResult);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.SaveEvaluationReview = SaveEvaluationReview;
function GetEvaluationReviewCommitments(vcc, evaluationPlanId, interactionId, supervisorId, agentId) {
    return new sql.Request(sqlConn)
        .input('VCC', sql.VarChar(50), vcc)
        .input('EvaluationPlanId', sql.VarChar(50), evaluationPlanId)
        .input('InteractionId', sql.VarChar(250), interactionId)
        .input('SupervisorId', sql.VarChar(50), supervisorId)
        .input('AgentId', sql.VarChar(50), agentId)
        .execute('GetEvaluationReviewCommitments')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetEvaluationReviewCommitments = GetEvaluationReviewCommitments;
function SaveEvaluationReviewCommitment(vcc, evaluationReviewCommitment, saveUserId) {
    return new sql.Request(sqlConn)
        .input('VCC', sql.VarChar(50), vcc)
        .input('EvaluationReviewId', sql.VarChar(50), evaluationReviewCommitment.evaluationReviewId)
        .input('Id', sql.VarChar(50), evaluationReviewCommitment.id)
        .input('LargeInteractionId', sql.VarChar(255), evaluationReviewCommitment.largeInteractionId)
        .input('AgentId', sql.VarChar(50), evaluationReviewCommitment.agentId)
        .input('Commitment', sql.VarChar(500), evaluationReviewCommitment.commitment)
        .input('SaveUserId', sql.VarChar(50), saveUserId)
        .execute('SaveEvaluationReviewCommitment')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
